
# nwjs-build [![npm version](https://img.shields.io/npm/v/nwjs-builder-phoenix.svg)](https://npmjs.org/package/nwjs-build) [![Standard Version](https://img.shields.io/badge/release-standard%20version-brightgreen.svg)](https://github.com/conventional-changelog/standard-version)

A possible solution to build and package a ready for distribution NW.js app for Windows, macOS and Linux.

## Why Bother?

We already had `nw-builder`, but it has made little progress on the way, and `nwjs-builder` has been hard to continue due to personal and historic reasons.

`electron-builder` inspired me when I became an Electron user later, loose files excluding, various target formats, auto updater, artifacts publishing and code signing, amazing!

Although NW.js has much lesser popularity than Electron, and is really troubled by historic headaches, let's have something modern.

## Features

* Building for Windows, macOS and Linux
  * Common: `zip`, `7z`
  * Windows: `nsis`, [`nsis7z`](https://github.com/evshiron/nwjs-builder-phoenix/docs/FAQs.md)
  * macOS: TODO
  * Linux: TODO
* Building for different platforms concurrently
* Configurable executable fields and icons for Windows and macOS
* Exclusion of loose files from `node_modules`
* [Chrome App support](https://github.com/evshiron/nwjs-builder-phoenix/docs/FAQs.md)
* `nwjs-ffmpeg-prebuilt` integration
* [Auto Updater](https://github.com/evshiron/nwjs-builder-phoenix/packages/nsis-compat-tester/)
* TODO Rebuilding native modules
* TODO Code signing
* Ideas appreciated :)

## Getting Started

* Make sure your NW.js project has a valid `package.json` (e.g. generated by `npm init`), and have basic fields like `name`, `description` and `version` filled.

* For apps destined for Mac, providing a `product_string` in the `package.json` will allow the Helper app to be [renamed for you](http://docs.nwjs.io/en/latest/For%20Users/Package%20and%20Distribute/#mac-os-x).

* Install `nwjs-build` as a `devDependencies` of your NW.js project as follows:

```shell
# Optional wine for building for Windows on other platforms.
# The command may differ in different Linux distributions.
#sudo apt-get install wine
npm install nwjs-build --save-dev
```

By installing it locally, `build` and `run` commands will be available in npm scripts. You can access option lists via `./node_modules/.bin/{ build, run } --help`.

DO NOT install it globally, as the command names are just too common.

* Add `build` properties at the root of the `package.json`, for example:

```json
// package.json
{
    "build": {
        "nwVersion": "0.14.7"
    }
}
```

This will specify the NW.js version we are using. See more in the following Options section.

* Add some helper npm scripts, for example:

```javascript
// package.json
{
    "scripts": {
        "dist": "build --tasks win-x86,win-x64,linux-x86,linux-x64,mac-x64 --mirror https://dl.nwjs.io/ .",
        "start": "run --x86 --mirror https://dl.nwjs.io/ ."
    }
}
```

The above code snippet enables `npm run dist` and `npm run start`/`npm start`. The former builds for all major platforms and both x86 and x64 arch, and the latter runs the project with x86 binaries, both with the specified version of NW.js and use specified mirror to accelerate the download.

* Well done.

This should be the common use case, read the following Options section and [FAQs](https://github.com/evshiron/nwjs-builder-phoenix/docs/FAQs.md) if something is missing.

See also [sample project](https://github.com/evshiron/nwjs-builder-phoenix/assets/project/) and [test cases](https://github.com/evshiron/nwjs-builder-phoenix/test/) for reference.

## Options

Passing and managing commandline arguments can be painful. In `nwjs-builder-phoenix`, we configure via the `build` property of the `package.json` of your NW.js project.

Also [see all available options here](./docs/Options.md).


If you have difficulties connecting to the official download source, you can specify a mirror via `--mirror` argument of both `build` and `run`, or by setting `NWJS_MIRROR` environment variable. Environment variables like `HTTP_PROXY`, `HTTPS_PROXY` and `ALL_PROXY` should be useful too.

* China Mainland
  * https://npm.taobao.org/mirrors/nwjs/
* Singapore
  * https://cnpmjs.org/mirrors/nwjs/

## License

MIT.